package dao

import (
	"github.com/jinzhu/gorm"
	"time"
)

//LampPoleGroup 灯杆分组
type LampPoleGroup struct {
	ID            int       `gorm:"primary_key" `       //编号
	PoleGroupName string    `gorm:"type:varchar(64)"`   //分组名称
	TenantId      string    `gorm:"type:varchar(12)"`   //租户ID
	CreateTime    time.Time `gorm:"type:datetime"`      //新增时间
	CreateUser    string    `gorm:"type:varchar(60)"`   //新增记录操作用户ID
	UpdateTime    time.Time `gorm:"type:datetime"`      //修改时间
	UpdateUser    string    `gorm:"type:varchar(60)"`   //修改用户
	IsDeleted     int       `gorm:"type:int;default 0"` //是否删除 0=未删除,1=删除
	Tag           string    `gorm:"type:varchar(255)"`  //标签，(备用，逗号区分)
	Remark        string    `gorm:"type:varchar(255)"`  //备注
	CountLampPole int       `gorm:"type:int"`           //灯杆数
}

func (LampPoleGroup) TableName() string {
	return "t_dev_lamp_pole_group"
}

func (c *LampPoleGroup) Delete() error {
	return GDb.Model(&c).Where("id = ?", c.ID).Updates(map[string]interface{}{"update_time": c.UpdateTime,
		"update_user": c.UpdateUser, "is_deleted": c.IsDeleted}).Error
}

func (c LampPoleGroup) IsExistedByName() bool {
	var count = 0
	_ = GDb.Model(&c).Where(" pole_group_name = ? and tenant_id = ? and is_deleted = ?",
		c.PoleGroupName, c.TenantId, c.IsDeleted).Count(&count).Error
	return count > 0
}

func (c LampPoleGroup) IsExistedByNameAndCode() bool {
	var devices []LampPoleGroup
	err := GDb.Model(&c).Where("pole_group_name = ? and tenant_id = ? and is_deleted = ?",
		c.PoleGroupName, c.TenantId, c.IsDeleted).Find(&devices).Error
	if gorm.IsRecordNotFoundError(err) {
		return false
	}
	for _, d := range devices {
		if d.ID != c.ID {
			return true
		}
	}
	return false
}

func (c *LampPoleGroup) Create() error {
	return GDb.Model(&c).Save(&c).Error
}

func (c *LampPoleGroup) Update() error {
	return GDb.Model(&c).Where(" id = ? ", c.ID).Updates(map[string]interface{}{"pole_group_name": c.PoleGroupName,
		"tenant_id": c.TenantId, "update_time": time.Now(), "update_user": "TODO", "is_deleted": 0}).Error
}

func (c *LampPoleGroup) GetDevice() error {
	err := GDb.Model(&c).Where(" id = ? ", c.ID).Scan(&c).Error
	return err
}

func (c LampPoleGroup) GetDevices(offset, limit int) ([]LampPoleGroup, error) {
	var devices []LampPoleGroup
	err := GDb.Model(&c).Where(" pole_group_name like ? ", "%"+c.PoleGroupName+"%").Offset(offset).Limit(limit).Find(&devices).Error
	return devices, err
}

func (c LampPoleGroup) GetAllDevices() ([]LampPoleGroup, error) {
	var devices []LampPoleGroup
	err := GDb.Model(&c).Where(" tenant_id = ? and is_deleted = ? ", c.TenantId, c.IsDeleted).Scan(&devices).Error
	return devices, err
}
